==> haskell-config-value-0.8.1-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-config-value.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 config-value
version:              0.8.1
visibility:           public
id:                   config-value-0.8.1-KeLFOkD4SXx3zqrwutdHEH
key:                  config-value-0.8.1-KeLFOkD4SXx3zqrwutdHEH
license:              MIT
copyright:            2015-2016,2019 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/config-value
synopsis:             Simple, layout-based value language similar to YAML or JSON
description:
    This package implements a language similar to YAML or JSON but
    with fewer special cases and fewer dependencies. It emphasizes
    layout structure for sections and lists, and requires quotes
    around strings.

category:             Language
abi:                  c518d3b2f9ee44bec17d50c4f9c419d2
exposed:              True
exposed-modules:      Config Config.Lens Config.Macro Config.Number
hidden-modules:
    Config.Lexer Config.LexerUtils Config.Parser Config.NumberParser
    Config.Tokens Config.Pretty Config.Value

import-dirs:          /usr/lib/ghc-9.0.1/site-local/config-value-0.8.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/config-value-0.8.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/config-value-0.8.1
hs-libraries:         HSconfig-value-0.8.1-KeLFOkD4SXx3zqrwutdHEH
depends:
    array-0.5.4.0 base-4.15.0.0 containers-0.6.4.1 pretty-1.1.3.6
    text-1.2.4.1

haddock-interfaces:
    /usr/share/doc/haskell-config-value/html/config-value.haddock

haddock-html:         /usr/share/doc/haskell-config-value/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-config-value-0.8.3-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-config-value.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 config-value
version:              0.8.3
visibility:           public
id:                   config-value-0.8.3-3pmzeYU8Vb25WTAZFoPyxS
key:                  config-value-0.8.3-3pmzeYU8Vb25WTAZFoPyxS
license:              MIT
copyright:            2015-2016,2019 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/config-value
synopsis:             Simple, layout-based value language similar to YAML or JSON
description:
    This package implements a language similar to YAML or JSON but
    with fewer special cases and fewer dependencies. It emphasizes
    layout structure for sections and lists, and requires quotes
    around strings.

category:             Language
abi:                  72a01865511e68988620c9a0fc21795b
exposed:              True
exposed-modules:      Config Config.Lens Config.Macro Config.Number
hidden-modules:
    Config.Lexer Config.LexerUtils Config.Parser Config.NumberParser
    Config.Tokens Config.Pretty Config.Value

import-dirs:          /usr/lib/ghc-9.0.2/site-local/config-value-0.8.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/config-value-0.8.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-config-value
hs-libraries:         HSconfig-value-0.8.3-3pmzeYU8Vb25WTAZFoPyxS
depends:
    array-0.5.4.0 base-4.15.1.0 containers-0.6.4.1 pretty-1.1.3.6
    text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-config-value/html/config-value.haddock

haddock-html:         /usr/share/doc/haskell-config-value/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
